Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6244)

Unified Diff: chrome/browser/ui/toolbar/chrome_toolbar_model.h

Issue 1314843007: Refactor connection_security into SecurityStateModel (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: create SecurityStateModel for chromeos login webview Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/tab_helpers.cc ('k') | chrome/browser/ui/toolbar/test_toolbar_model.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/toolbar/chrome_toolbar_model.h
diff --git a/chrome/browser/ui/toolbar/chrome_toolbar_model.h b/chrome/browser/ui/toolbar/chrome_toolbar_model.h
index aa14d6912f589129374eb579c2d3b676ddd51105..e6320aa1a2af08453cd10326d5766341af06c751 100644
--- a/chrome/browser/ui/toolbar/chrome_toolbar_model.h
+++ b/chrome/browser/ui/toolbar/chrome_toolbar_model.h
@@ -5,11 +5,11 @@
#ifndef CHROME_BROWSER_UI_TOOLBAR_CHROME_TOOLBAR_MODEL_H_
#define CHROME_BROWSER_UI_TOOLBAR_CHROME_TOOLBAR_MODEL_H_
-#include "chrome/browser/ssl/connection_security.h"
+#include "chrome/browser/ssl/security_state_model.h"
#include "components/toolbar/toolbar_model.h"
// This class is a //chrome-specific extension of the ToolbarModel interface.
// TODO(blundell): If connection_security::SecurityLevel gets componentized,
// GetSecurityLevel() can be folded into ToolbarModel and this class can go
// away. crbug.com/515071
class ChromeToolbarModel : public ToolbarModel {
@@ -20,7 +20,7 @@ class ChromeToolbarModel : public ToolbarModel {
// |ignore_editing| is true, the result reflects the underlying state of the
// page without regard to any user edits that may be in progress in the
// omnibox.
- virtual connection_security::SecurityLevel GetSecurityLevel(
+ virtual SecurityStateModel::SecurityLevel GetSecurityLevel(
bool ignore_editing) const = 0;
protected:
« no previous file with comments | « chrome/browser/ui/tab_helpers.cc ('k') | chrome/browser/ui/toolbar/test_toolbar_model.h » ('j') | no next file with comments »
@@ -5,11 +5,11 @@
#include "components/toolbar/toolbar_model.h"
// This class is a //chrome-specific extension of the ToolbarModel interface.
-// TODO(blundell): If connection_security::SecurityLevel gets componentized,
+// TODO(blundell): If SecurityStateModel::SecurityLevel gets componentized,
// GetSecurityLevel() can be folded into ToolbarModel and this class can go
// away. crbug.com/515071

Powered by Google App Engine
This is Rietveld 408576698